local _,rematch = ...
local L = rematch.localization
local C = rematch.constants
local settings = rematch.settings
rematch.targetMenu = {}
local tm = rematch.targetMenu

rematch.events:Register(rematch.targetMenu,"PLAYER_LOGIN",function(self)

    -- menu when you right-click a target in the target list
    local targetMenu = {
        {title=tm.GetTargetName},
        {text=L["Edit Target"], func=tm.SetTeams},
        {text=L["Load Saved Team"], hidden=tm.NoSavedTeam, func=tm.LoadSavedTeam},
        {text=L["Load Random Pets"], func=tm.LoadRandomTeam},
        {text=CANCEL},
    }
    rematch.menus:Register("TargetMenu",targetMenu)

    rematch.dialog:Register("SetTargetTeams",{
        title=L["Edit Target"],
        accept=SAVE,
        cancel=CANCEL,
        width = 290,
        layout={"Text","TeamPicker","Help"},
        refreshFunc = function(self,info,subject,firstRun)
            if firstRun then
                rematch.dialog:SetTitle(rematch.targetInfo:GetNpcName(subject.targetID))
                self.Text:SetText(format(L["These are the teams saved for %s."],rematch.utils:GetFormattedTargetName(subject.targetID)))
                self.Help:SetText(L["The topmost team is the preferred team to load when you interact with this target."])
                self.TeamPicker:SetList(subject.listType,subject.list)
            end
        end,
        acceptFunc = function(self,info,subject)
            local npcID = rematch.targetInfo:GetNpcID(subject.targetID)
            if npcID then
                rematch.savedTargets:Set(npcID,self.TeamPicker:GetList())
                rematch.targetsPanel.List:BlingData(subject.targetID)
            end
        end
    })

end)

function rematch.targetMenu:GetTargetName(npcID)
    return rematch.targetInfo:GetNpcName(npcID)
end

function rematch.targetMenu:SetTeams(targetID)
    local list = {}
    if rematch.savedTargets[targetID] then
        for _,npcID in ipairs(rematch.savedTargets[targetID]) do
            tinsert(list,npcID)
        end
    end
    rematch.dialog:ShowDialog("SetTargetTeams",{targetID=targetID, listType=C.LIST_TYPE_TEAM, list=list})
end

function rematch.targetMenu:LoadRandomTeam(targetID)
    local npcID = rematch.targetInfo:GetNpcID(targetID)
    if npcID then
        rematch.loadedTargetPanel:SetTarget(npcID,true)
    end
    rematch.randomPets:BuildCounterTeam(npcID)
    rematch.loadTeam:LoadTeamID("counter")
end

function rematch.targetMenu:NoSavedTeam(targetID)
    return not rematch.savedTargets[targetID]
end

function rematch.targetMenu:LoadSavedTeam(targetID)
    local teams,index = rematch.savedTargets:GetTeams(targetID)
    if teams and index and teams[index] then
        rematch.loadTeam:LoadTeamID(teams[index])
    end
end